@@ -329,6 +329,13 @@ sub check_device {
     return if ($self->{last_test_write}{$devid} || 0) + UPDATE_DB_EVERY > $now;
     $self->{last_test_write}{$devid} = $now;
 
+    unless ($dev->can_delete_from) {
+        # we should not try to write on readonly devices because it can be # mounted as RO.
+        $self->state_event('device', $devid, {observed_state => 'readable'})
+            if (!$dev->observed_readable);
+        debug("dev$devid: used = $used, total = $total, writeable = 0");
+        return;
+    }
     # now we want to check if this device is writeable
 
     # first, create the test-write directory.  this will return
