@@ -10,7 +10,6 @@ use fields (
 use List::Util ();
 use MogileFS::Util qw(error every debug);
 use MogileFS::Config;
-use MogileFS::Class;
 use MogileFS::ReplicationRequest qw(rr_upgrade);
 
 # setup the value used in a 'nexttry' field to indicate that this item will never
@@ -33,18 +32,7 @@ sub watchdog_timeout { 90; }
 sub work {
     my $self = shift;
 
-    # give the monitor job 15 seconds to give us an update
-    my $warn_after = time() + 15;
-
     every(1.0, sub {
-        # replication doesn't go well if the monitor job hasn't actively started
-        # marking things as being available
-        unless ($self->monitor_has_run) {
-            error("waiting for monitor job to complete a cycle before beginning replication")
-                if time() > $warn_after;
-            return;
-        }
-
         $self->send_to_parent("worker_bored 100 replicate rebalance");
 
         my $queue_todo  = $self->queue_todo('replicate');
@@ -181,7 +169,7 @@ sub replicate_using_torepl_table {
         my $devfid;
         # First one we can delete from, we try to rebalance away from.
         for (@devs) {
-            my $dev = MogileFS::Device->of_devid($_);
+            my $dev = Mgd::device_factory()->get_by_id($_);
             # Not positive 'can_read_from' needs to be here.
             # We must be able to delete off of this dev so the fid can
             # move.
@@ -361,7 +349,7 @@ sub replicate {
     };
 
     # hashref of devid -> MogileFS::Device
-    my $devs = MogileFS::Device->map
+    my $devs = Mgd::device_factory()->map_by_id
         or die "No device map";
 
     return $retunlock->(0, "failed_getting_lock", "Unable to obtain lock for fid $fidid")
@@ -380,7 +368,7 @@ sub replicate {
     my @on_up_devid;     # subset of @on_devs:  just devs that are readable
 
     foreach my $devid ($fid->devids) {
-        my $d = MogileFS::Device->of_devid($devid)
+        my $d = Mgd::device_factory()->get_by_id($devid)
             or next;
         push @on_devs, $d;
         if ($d->dstate->should_have_files && ! $mask_devids->{$devid}) {
@@ -571,11 +559,11 @@ sub http_copy {
     };
 
     # get some information we'll need
-    my $sdev = MogileFS::Device->of_devid($sdevid);
-    my $ddev = MogileFS::Device->of_devid($ddevid);
+    my $sdev = Mgd::device_factory()->get_by_id($sdevid);
+    my $ddev = Mgd::device_factory()->get_by_id($ddevid);
 
     return error("Error: unable to get device information: source=$sdevid, destination=$ddevid, fid=$fid")
-        unless $sdev && $ddev && $sdev->exists && $ddev->exists;
+        unless $sdev && $ddev;
 
     my $s_dfid = MogileFS::DevFID->new($sdev, $fid);
     my $d_dfid = MogileFS::DevFID->new($ddev, $fid);
